{% extends "base_config.html" %} {% block content %}

Hold up! Our Automations are taking a well-deserved break for some maintenance magic. They'll be back in action soon, better than ever. Thanks for your patience!

Back to Chat

## Automate (Preview)
Automations allow you to schedule smart reminders using Khoj. This is an experimental feature, so your results may vary! Send any feedback to team@khoj.dev.
Sending automation results to {{ username }}.

## Suggested Automations

{% endblock %}